# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class PageImageRegistryRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'PageImageRegistry','sas')
		self.set_protocol_type('https')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_RegistryTypeNotInLists(self): # RepeatList
		return self.get_body_params().get('RegistryTypeNotInList')

	def set_RegistryTypeNotInLists(self, RegistryTypeNotInList):  # RepeatList
		for depth1 in range(len(RegistryTypeNotInList)):
			self.add_body_params('RegistryTypeNotInList.' + str(depth1 + 1), RegistryTypeNotInList[depth1])
	def get_SourceIp(self): # String
		return self.get_query_params().get('SourceIp')

	def set_SourceIp(self, SourceIp):  # String
		self.add_query_param('SourceIp', SourceIp)
	def get_PageSize(self): # Integer
		return self.get_body_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_body_params('PageSize', PageSize)
	def get_RegistryNameLike(self): # String
		return self.get_body_params().get('RegistryNameLike')

	def set_RegistryNameLike(self, RegistryNameLike):  # String
		self.add_body_params('RegistryNameLike', RegistryNameLike)
	def get_CurrentPage(self): # Integer
		return self.get_body_params().get('CurrentPage')

	def set_CurrentPage(self, CurrentPage):  # Integer
		self.add_body_params('CurrentPage', CurrentPage)
	def get_RegistryTypeInLists(self): # RepeatList
		return self.get_body_params().get('RegistryTypeInList')

	def set_RegistryTypeInLists(self, RegistryTypeInList):  # RepeatList
		for depth1 in range(len(RegistryTypeInList)):
			self.add_body_params('RegistryTypeInList.' + str(depth1 + 1), RegistryTypeInList[depth1])
